import React from 'react'
import { get } from 'lodash'
import { reduxForm } from 'redux-form'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { required } from 'xpub-validators'
import { compose, withProps } from 'recompose'
import { Button, Menu, ValidatedField } from '@pubsweet/ui'
import { withModal } from 'pubsweet-component-modal/src/components'

import {
  Row,
  Text,
  Label,
  Textarea,
  MultiAction,
  ContextualBox,
  ItemOverrideAlert,
  withFetching,
} from '../'

const options = [
  { value: 'publish', label: 'Publish' },
  { value: 'reject', label: 'Reject' },
  { value: 'minor-revision', label: 'Request Minor Revision' },
  { value: 'major-revision', label: 'Request Major Revision' },
]

const EditorialRecommendation = ({ formValues, handleSubmit }) => (
  <ContextualBox highlight label="Your Editorial Recommendation" startExpanded>
    <Root>
      <Row justify="flex-start">
        <ItemOverrideAlert flex={0} vertical>
          <Label required>Recommendation</Label>
          <ValidatedField
            component={input => <Menu options={options} {...input} />}
            name="recommendation"
            validate={[required]}
          />
        </ItemOverrideAlert>
      </Row>

      {get(formValues, 'recommendation') === 'publish' ||
      get(formValues, 'recommendation') === 'reject' ? (
        <Row mt={2}>
          <ItemOverrideAlert vertical>
            <Label required>Message for Author</Label>
            <ValidatedField
              component={Textarea}
              name="message"
              validate={[required]}
            />
          </ItemOverrideAlert>
        </Row>
      ) : (
        <Row mt={2}>
          <ItemOverrideAlert mr={1} vertical>
            <Label>
              Message for Author <Text secondary>Optional</Text>
            </Label>
            <ValidatedField component={Textarea} name="author-message" />
          </ItemOverrideAlert>

          <ItemOverrideAlert ml={1} vertical>
            <Label>
              Message for Editor in Chief <Text secondary>Optional</Text>
            </Label>
            <ValidatedField component={Textarea} name="eic-message" />
          </ItemOverrideAlert>
        </Row>
      )}

      <Row justify="flex-end" mt={2}>
        <Button onClick={handleSubmit} primary size="medium">
          Submit recommendation
        </Button>
      </Row>
    </Root>
  </ContextualBox>
)

export default compose(
  withFetching,
  withModal(({ isFetching }) => ({
    isFetching,
    modalComponent: MultiAction,
  })),
  withProps(({ formValues }) => ({
    modalTitle: options.find(
      o => o.value === get(formValues, 'recommendation', 'publish'),
    ).label,
  })),
  reduxForm({
    form: 'editorialRecommendation',
    onSubmit: (
      values,
      dispatch,
      { onRecommendationSubmit, showModal, setFetching, modalTitle },
    ) => {
      showModal({
        title: `${modalTitle}?`,
        onConfirm: props => {
          onRecommendationSubmit(values, { ...props, setFetching })
        },
      })
    },
  }),
)(EditorialRecommendation)

// #region styles
const Root = styled.div`
  display: flex;
  flex-direction: column;
  padding: ${th('gridUnit')};
`
// #endregion
